@@ -2,6 +2,6 @@
 # Author: Jason Costello <jason@hypervector.io>
 
 API_KEY = None
-API_BASE = "http://api.hypervector.io/v1"
+API_BASE = "https://api.hypervector.io/v1"
 
 from hypervector.resources.core import *
